==> texinfo-6.6.91.tar.xz: texinfo-6.6.91/tp/t/results/info_tests/file_only_png.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text);

use utf8;

$result_trees{'file_only_png'} = {
  'contents' => [
    {
      'contents' => [],
      'parent' => {},
      'type' => 'text_root'
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Top'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Just before an image '
            },
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'this_is_a_long_unknown_file'
                    }
                  ],
                  'parent' => {},
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'image',
              'contents' => [],
              'extra' => {
                'input_perl_encoding' => 'utf-8'
              },
              'line_nr' => {
                'file_name' => '',
                'line_nr' => 3,
                'macro' => ''
              },
              'parent' => {}
            },
            {
              'parent' => {},
              'text' => ' text after the image, and more text, and more '
            },
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'this_is_a_long_unknown_file'
                    }
                  ],
                  'parent' => {},
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'image',
              'contents' => [],
              'extra' => {
                'input_perl_encoding' => 'utf-8'
              },
              'line_nr' => {},
              'parent' => {}
            },
            {
              'parent' => {},
              'text' => ' text.
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        }
      ],
      'extra' => {
        'node_content' => [
          {}
        ],
        'nodes_manuals' => [
          {
            'node_content' => [],
            'normalized' => 'Top'
          }
        ],
        'normalized' => 'Top',
        'spaces_before_argument' => ' '
      },
      'line_nr' => {
        'file_name' => '',
        'line_nr' => 1,
        'macro' => ''
      },
      'parent' => {}
    }
  ],
  'type' => 'document_root'
};
$result_trees{'file_only_png'}{'contents'}[0]{'parent'} = $result_trees{'file_only_png'};
$result_trees{'file_only_png'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'args'}[0];
$result_trees{'file_only_png'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'line_nr'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'line_nr'};
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'file_only_png'}{'contents'}[1]{'args'}[0]{'contents'}[0];
$result_trees{'file_only_png'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'file_only_png'}{'contents'}[1]{'extra'}{'node_content'};
$result_trees{'file_only_png'}{'contents'}[1]{'parent'} = $result_trees{'file_only_png'};

$result_texis{'file_only_png'} = '@node Top

Just before an image @image{this_is_a_long_unknown_file} text after the image, and more text, and more @image{this_is_a_long_unknown_file} text.
';


$result_texts{'file_only_png'} = '
Just before an image this_is_a_long_unknown_file text after the image, and more text, and more this_is_a_long_unknown_file text.
';

$result_sectioning{'file_only_png'} = {};

$result_nodes{'file_only_png'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top',
    'spaces_before_argument' => ' '
  }
};

$result_menus{'file_only_png'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top',
    'spaces_before_argument' => ' '
  }
};

$result_errors{'file_only_png'} = [];



$result_converted{'info'}->{'file_only_png'} = 'This is , produced from .


File: ,  Node: Top,  Up: (dir)

Just before an image  [image src="this_is_a_long_unknown_file.png" ] text after the image, and more text, and more  [image src="this_is_a_long_unknown_file.png" ]
text.


Tag Table:
Node: Top27

End Tag Table


Local Variables:
coding: utf-8
End:
';

1;

==> texinfo-6.8.90.tar.xz: texinfo-6.8.90/tp/t/results/info_tests/file_only_png.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'file_only_png'} = {
  'contents' => [
    {
      'parent' => {},
      'type' => 'before_node_section'
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Top'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'node',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Just before an image '
            },
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'this_is_a_long_unknown_file'
                    }
                  ],
                  'parent' => {},
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'image',
              'extra' => {
                'input_perl_encoding' => 'utf-8'
              },
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 3,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => ' text after the image, and more text, and more '
            },
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'this_is_a_long_unknown_file'
                    }
                  ],
                  'parent' => {},
                  'type' => 'brace_command_arg'
                }
              ],
              'cmdname' => 'image',
              'extra' => {
                'input_perl_encoding' => 'utf-8'
              },
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 3,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => ' text.
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        }
      ],
      'extra' => {
        'node_content' => [
          {}
        ],
        'nodes_manuals' => [
          {
            'node_content' => [
              {}
            ],
            'normalized' => 'Top'
          }
        ],
        'normalized' => 'Top',
        'spaces_before_argument' => ' '
      },
      'parent' => {},
      'source_info' => {
        'file_name' => '',
        'line_nr' => 1,
        'macro' => ''
      }
    }
  ],
  'type' => 'document_root'
};
$result_trees{'file_only_png'}{'contents'}[0]{'parent'} = $result_trees{'file_only_png'};
$result_trees{'file_only_png'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'args'}[0];
$result_trees{'file_only_png'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1];
$result_trees{'file_only_png'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'file_only_png'}{'contents'}[1]{'args'}[0]{'contents'}[0];
$result_trees{'file_only_png'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'file_only_png'}{'contents'}[1]{'args'}[0]{'contents'}[0];
$result_trees{'file_only_png'}{'contents'}[1]{'parent'} = $result_trees{'file_only_png'};

$result_texis{'file_only_png'} = '@node Top

Just before an image @image{this_is_a_long_unknown_file} text after the image, and more text, and more @image{this_is_a_long_unknown_file} text.
';


$result_texts{'file_only_png'} = '
Just before an image this_is_a_long_unknown_file text after the image, and more text, and more this_is_a_long_unknown_file text.
';

$result_nodes{'file_only_png'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top'
  }
};

$result_menus{'file_only_png'} = {
  'cmdname' => 'node',
  'extra' => {
    'normalized' => 'Top'
  }
};

$result_errors{'file_only_png'} = [];


$result_floats{'file_only_png'} = {};



$result_converted{'info'}->{'file_only_png'} = 'This is , produced from .


File: ,  Node: Top,  Up: (dir)

Just before an image  [image src="this_is_a_long_unknown_file.png" ] text after the image, and more text, and more  [image src="this_is_a_long_unknown_file.png" ]
text.


Tag Table:
Node: Top27

End Tag Table


Local Variables:
coding: utf-8
End:
';

1;
